/*globals require, window*/

require([
    'jquery',
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/shop/ui/regiondialog-test',
    '$dict!de_epages/shop/ui/regiondialog',

    'jquery/tmpl',
    'de_epages/shop/ui/regiondialog'
], function ($, QUnit, fixture, dict) {
    'use strict';

    var countryIDs = ["266", "275", "276", "548", "660", "876"],
        newAlias = "dolle-wuasd-region";

    ep.ajax = function (o) {
        var result = $.Deferred();

        if (o.data && o.data.ChangeAction === 'UnityEditRegion') {

            if (o.data.Alias === 'region one') {
                result.resolve({
                    "success": false,
                    "error": [{
                        "reason": "OBJECT_EXISTS"
                    }]
                });
            } else if (o.data.Alias === newAlias) {
                result.resolve({
                    "success": true
                });
            }
        }

        return result;
    };


    QUnit.module('de_epages/shop/ui/regiondialog', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest('check presence/existence of methods', 8, function () {
        // check prototype methods
        $.each([
            '_init',
            '_openDialog',
            '_initTooltip',
            '_handleTooltip',
            '_handleClick',
            '_handleSubmit',
            '_handleError',
            'destroy'
        ], function (i, fn) {
            QUnit.equal(
                $.isFunction($.ui.shopUiRegiondialog.prototype[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );

        });

        // run tests
        QUnit.start();
    });

    QUnit.asyncTest('test widget functionalities', 12, function () {
        /*
         * @dictionary              ep.dict
         *
         * @translation             {Cancel}
         *                          {Save}
         *                          {UnknownError}
         *
         * @dictionary              de_epages.shop.dictionary
         *
         * @translation             {AliasMissing}
         *                          {DoubleRegion}
         *                          {NoCountrySelected}
         *
         * @dictionary              de_epages.shop.ui.regiondialog
         *
         * @translation             {DoubleRegion}
         */

        var translations = {
                cancel: dict.translate('Cancel'),
                save: dict.translate('Save'),
                NoCountrySelected: dict.translate('NoCountrySelected'),
                AliasMissing: dict.translate('AliasMissing'),
                OBJECT_EXISTS: dict.translate('DoubleRegion'),
                defaultError: dict.translate('UnknownError')
            },

            widget,
            regionRow,
            data,
            tmpData;

        QUnit.equal(
            $('#ep-add-new-item-tmpl').tmpl().find('.DialogError').length,
            1,
            "template contains one element with error class 'DialogError'"
        );

        // initialize widget
        $('.ep-regions-table').shopUiRegiondialog({
            dlgTmpl: $('#ep-add-new-item-tmpl')
        });

        widget = $('.ep-regions-table').data('uiShopUiRegiondialog');

        QUnit.equal(
            $('.ep-regions-table').data('uiShopUiRegiondialog').tmpl.find('.DialogError').length,
            0,
            "element with error class 'DialogError' was removed"
        );

        // get first region row
        regionRow = $('.ep-regions-table tbody tr:first');
        // get original data from dom element
        data = regionRow.data('regions');
        // trigger click on first row
        regionRow.find('.ep-regions-link').trigger('click');

        window.setTimeout(function() {

            widget.dialog.find('input[name=ListObjectID]:checked').each(function(index, elem) {
                QUnit.ok(widget.dialog.is(':visible') === true, 'dialog is visible');
            });

            QUnit.equal(
                widget.dialog.find('input[name=NewAlias]').val(),
                data.alias,
                "element with error class 'DialogError' was removed"
            );

            widget.dialog.find('input[name=ListObjectID]:checked').each(function(index, elem) {
                QUnit.ok(data.selectedCountries.indexOf(elem.value) > -1, 'region with ID ' + elem.value + ' is checked');
            });

            widget.dialog.closest('.ui-dialog').find('.ep-button-add').trigger('click');

            // wait for ajax response
            window.setTimeout(function() {
                QUnit.ok($('.ep-uiTooltip').length === 1, 'an error occurs');

                QUnit.equal(
                    widget.tooltip.html(),
                    translations['OBJECT_EXISTS'],
                    "error thrown - a region with the same alias already exists"
                );

                // get data from dom element
                tmpData = regionRow.data('regions');

                QUnit.ok((data.alias === tmpData.alias && data.selectedCountries.sort().join('') === tmpData.selectedCountries.sort().join('')) === true, 'due to an error original data were not changed');

                // open dialog again
                regionRow.find('.ep-regions-link').trigger('click');

                // wait for ajax response
                window.setTimeout(function() {
                    // uncheck all countries
                    widget.dialog.find('input[name=ListObjectID]:checked').prop('checked', false);

                    // try to submit dialog data
                    widget.dialog.closest('.ui-dialog').find('.ep-button-add').trigger('click');

                    QUnit.equal(
                        widget.tooltip.html(),
                        translations['NoCountrySelected'],
                        "error thrown - no country was selected"
                    );

                    // check all countries
                    widget.dialog.find('input[name=ListObjectID]').prop('checked', true);
                    // insert new alias
                    widget.dialog.find('input[name=NewAlias]').val(newAlias);

                    widget.dialog.closest('.ui-dialog').find('.ep-button-add').trigger('click');

                    // get data from dom element
                    tmpData = regionRow.data('regions');
                    QUnit.ok((newAlias === tmpData.alias && countryIDs.join('') === tmpData.selectedCountries.sort().join('')) === true, 'new data values were stored in data attribute');

                    // close dialog again
                    widget.dialog.uiDialog('close');

                    // run tests
                    QUnit.start();
                }, 200);
            }, 100);
        }, 200);
    });
});