/*global define*/
/*jslint browser:true*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/chronopost/ui/pointrelais-test.html',
    'jquery',
    'de_epages/chronopost/ui/pointrelais'
], function (QUnit, fixture, $) {

    'use strict';

    QUnit.module("de_epages/chronopost/ui/pointrelais", {
        setup: fixture.init,
        teardown: fixture.destroy
    });


    ep.ajax = function (o) {
        var result = $.Deferred();

        if (o.data && o.data.ViewAction === 'JSONViewChronopostLocations') {
            if (o.data.ZipCode === "45000") {
                result.resolve([{
                    "urlGMaps": "http://maps.google.fr/maps?q=47.9102777778,1.90805555556",
                    "longitude": "1.90805555556",
                    "name": "LA MAISON DES TABACS",
                    "zipcode": "45000",
                    "city": "ORLEANS",
                    "latitude": "47.9102777778",
                    "address": "46 RUE EMILE ZOLA",
                    "id": "8300P"
                }, {
                    "urlGMaps": "http://maps.google.fr/maps?q=47.9102777778,1.90055555556",
                    "longitude": "1.90055555556",
                    "name": "1001 PILES BATTERIES",
                    "zipcode": "45000",
                    "city": "ORLEANS",
                    "latitude": "47.9102777778",
                    "address": "64 RUE DU FAUBOURG BANNIER",
                    "id": "0571R"
                }, {
                    "urlGMaps": "http://maps.google.fr/maps?q=47.90314,1.904047",
                    "longitude": "1.904047",
                    "name": "NUMERICABLE",
                    "zipcode": "45000",
                    "city": "Orleans",
                    "latitude": "47.90314",
                    "address": "6 RUE DE LA REPUBLIQUE",
                    "id": "0448R"
                }, {
                    "urlGMaps": "http://maps.google.fr/maps?q=47.9041666667,1.90111111111",
                    "longitude": "1.90111111111",
                    "name": "LE PETIT BOUCHON DE LA LIONNE",
                    "zipcode": "45000",
                    "city": "ORLEANS",
                    "latitude": "47.9041666667",
                    "address": "19 RUE DE LA LIONNE",
                    "id": "0252R"
                }, {
                    "urlGMaps": "http://maps.google.fr/maps?q=47.9013888889,1.90444444444",
                    "longitude": "1.90444444444",
                    "name": "LISSAC OPTICIEN",
                    "zipcode": "45000",
                    "city": "ORLEANS",
                    "latitude": "47.9013888889",
                    "address": "30 RUE JEANNE DARC",
                    "id": "7526P"
                }]);
            } else {
                result.resolve([]);
            }
        }

        return result;
    };


    QUnit.asyncTest('Show point relais to pick up the package (5 point relais found)', 9, function () {

        $('#ChronopostPointrelais')
            .chronopostUiPointrelais({
                zipcode: '45000',
                relaisId: '0'
            });

        setTimeout(function () {

            QUnit.equal(
                $('.PointRelaisZipCode').val(),
                45000,
                '45000 value found in the PointRelaisZipCode input'
            );

            QUnit.equal(
                $('.map_canvas').length,
                1,
                'Check if the map item exists'
            );

            QUnit.ok(
                $('.map_canvas *').length,
                'Check if the map item is not empty'
            );

            QUnit.equal(
                $('.locations tr').length,
                5,
                '5 rows with point relais in the table'
            );

            QUnit.equal(
                $('.locations tr:eq(0) input[name=location]').val(),
                '8300P-LA MAISON DES TABACS-46 RUE EMILE ZOLA-45000-ORLEANS',
                'Check value of the first radio element'
            );

            QUnit.equal(
                $('.locations tr:eq(1) input[name=location]').val(),
                '0571R-1001 PILES BATTERIES-64 RUE DU FAUBOURG BANNIER-45000-ORLEANS',
                'Check value of the second radio element'
            );

            QUnit.equal(
                $('.locations tr:eq(2) input[name=location]').val(),
                '0448R-NUMERICABLE-6 RUE DE LA REPUBLIQUE-45000-Orleans',
                'Check value of the third radio element'
            );

            QUnit.equal(
                $('.locations tr:eq(3) input[name=location]').val(),
                '0252R-LE PETIT BOUCHON DE LA LIONNE-19 RUE DE LA LIONNE-45000-ORLEANS',
                'Check value of the fourth radio element'
            );

            QUnit.equal(
                $('.locations tr:eq(4) input[name=location]').val(),
                '7526P-LISSAC OPTICIEN-30 RUE JEANNE DARC-45000-ORLEANS',
                'Check value of the fifth radio element'
            );

            QUnit.start();
        }, 5000);

    });

    QUnit.asyncTest('Show point relais to pick up the package (no point relais found)', 4, function () {

        $('#ChronopostPointrelais')
            .chronopostUiPointrelais({
                zipcode: 'dtgrf',
                relaisId: '0'
            });

        setTimeout(function () {

            QUnit.equal(
                $('.PointRelaisZipCode').val(),
                'dtgrf',
                'dtgrf value found in the PointRelaisZipCode input'
            );

            QUnit.equal(
                $('.map_canvas').length,
                1,
                'Check if the map item exists'
            );

            QUnit.ok(
                $('.map_canvas *').length,
                'Check if the map item is not empty'
            );

            QUnit.equal(
                $('.locations tr').length,
                0,
                '0 rows with point relais in the table'
            );

            QUnit.start();
        }, 5000);

    });
});